@@ -1,20 +1,14 @@
 # -*- coding: utf-8 -*-
-# NOTE: Every type ignore in this module is necessary due to
-# false-positive bugs in mypy.  Feel free to remove them as they'll be
-# fixed.  See GitHub issues for more info:
-# `https://github.com/python/mypy/issues/1105`,
-# `https://github.com/python/mypy/issues/1106`,
-# `https://github.com/python/mypy/issues/1107`.
 
 
 try:
     from enum import Enum, EnumMeta
 except ImportError:
     # We are on Python 2.7 and enum34 package is not installed.
-    class Enum(object):  # type: ignore
+    class Enum(object):
         pass
 
-    class EnumMeta(object):  # type: ignore
+    class EnumMeta(object):
         pass
 
 
@@ -23,18 +17,40 @@ try:
     from pydantic.main import ModelMetaclass as PydanticSpec
 except ImportError:
     # Pydantic package is not installed.
-    class PydanticSpec(object):  # type: ignore
+    class PydanticSpec(object):
         pass
 
-    class PydanticError(object):  # type: ignore
+    class PydanticError(object):
         pass
 
 
 try:
-    from marshmallow.schema import SchemaMeta as MarshmallowSpec
+    import marshmallow
+
+    if marshmallow.__version_info__[0] != 3:
+        raise ImportError
+
+    from marshmallow.schema import SchemaMeta as Marshmallow3Spec
+    from marshmallow.exceptions import ValidationError as Marshmallow3Error
 except ImportError:
-    # Marshmallow package is not installed.
-    class MarshmallowSpec(object):  # type: ignore
+    # Marshmallow 3 package is not installed.
+    class Marshmallow3Spec(object):
+        pass
+
+    class Marshmallow3Error(object):
+        pass
+
+
+try:
+    import marshmallow
+
+    if marshmallow.__version_info__[0] != 2:
+        raise ImportError
+
+    from marshmallow.schema import SchemaMeta as Marshmallow2Spec
+except ImportError:
+    # Marshmallow 2 package is not installed.
+    class Marshmallow2Spec(object):
         pass
 
 
@@ -42,7 +58,7 @@ try:
     from cerberus import Validator as CerberusSpec
 except ImportError:
     # Cerberus package is not installed.
-    class CerberusSpec(object):  # type: ignore
+    class CerberusSpec(object):
         pass
 
 
@@ -50,7 +66,7 @@ try:
     from textwrap import indent
 except ImportError:
     # We are on Python 2.7
-    def indent(text, prefix):  # type: ignore
+    def indent(text, prefix):
         return "".join(map(lambda l: prefix + l, text.splitlines(True)))
 
 
